@@ -519,8 +519,8 @@ impl RustGenerator {
             AbiType::Object(ident) => quote!(#ident),
             AbiType::RefObject(ident) => quote!(&#ident),
             AbiType::Tuple(ty) => quote!((#(for ty in ty => #(self.ty(ty)),))),
-            AbiType::RefIter(ty) => quote!(&impl IntoIterator<Item = #(self.ty(ty))>),
-            AbiType::Iter(ty) => quote!(impl IntoIterator<Item = #(self.ty(ty))>),
+            AbiType::RefIter(ty) => quote!(&Vec<#(self.ty(ty))>),
+            AbiType::Iter(ty) => quote!(Vec<#(self.ty(ty))>),
             AbiType::RefFuture(ty) => quote!(&impl Future<Output = #(self.ty(ty))>),
             AbiType::Future(ty) => quote!(impl Future<Output = #(self.ty(ty))>),
             AbiType::RefStream(ty) => quote!(&impl Stream<Item = #(self.ty(ty))>),
